=============================
Cell Maps Generate Hierarchy
=============================


.. image:: https://img.shields.io/pypi/v/cellmaps_generate_hierarchy.svg
        :target: https://pypi.python.org/pypi/cellmaps_generate_hierarchy

.. image:: https://img.shields.io/travis/idekerlab/cellmaps_generate_hierarchy.svg
        :target: https://travis-ci.com/idekerlab/cellmaps_generate_hierarchy

Generates hierarchy from `Cell Maps Coembedding <https://cellmaps-coembedding.readthedocs.io/>`__
for `Cell Maps for AI (CM4AI) <https://cm4ai.org>`__

* Free software: MIT license


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   developer
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
